@@ -32,13 +32,14 @@
 #include <string.h>
 
 #include "string_match.h"
+#include "utils.h"
 
 int string_match_precompile (gchar *rexp, regex_t *preg, int cflags)
 {
 	int problem = 0;
 
-	g_return_val_if_fail(rexp, -1);
-	g_return_val_if_fail(*rexp, -1);
+	cm_return_val_if_fail(rexp, -1);
+	cm_return_val_if_fail(*rexp, -1);
 
 	problem = regcomp(preg, rexp, cflags);  
 	
