@@ -1,6 +1,6 @@
 /*
  * Claws Mail -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 2005-2007 DINH Viet Hoa and the Claws Mail team
+ * Copyright (C) 2005-2009 DINH Viet Hoa and the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -1437,7 +1437,7 @@ int imap_threaded_select(Folder * folder, const char * mb,
 					flag->fl_flag->fl_type == 6 &&
 					!strcmp(flag->fl_flag->fl_data.fl_extension, "*"))
 				*can_create_flags = TRUE; 
-			if (ok_flags) {
+			if (flag->fl_flag && ok_flags) {
 				MsgPermFlags c_flag = 0;
 				switch (flag->fl_flag->fl_type) {
 				case MAILIMAP_FLAG_ANSWERED:
@@ -2459,7 +2459,7 @@ static void fetch_content_run(struct etpan_thread_op * op)
 	result->error = r;
 	
 	if (r == MAILIMAP_NO_ERROR) {
-		fd = open(param->filename, O_RDWR | O_CREAT, 0600);
+		fd = g_open(param->filename, O_RDWR | O_CREAT, 0600);
 		if (fd < 0) {
 			result->error = MAILIMAP_ERROR_FETCH;
 			goto free;
@@ -2960,7 +2960,7 @@ static void append_run(struct etpan_thread_op * op)
 	}
 	size = stat_buf.st_size;
 	
-	fd = open(param->filename, O_RDONLY);
+	fd = g_open(param->filename, O_RDONLY, 0);
 	if (fd < 0) {
 		result->error = MAILIMAP_ERROR_APPEND;
 		return;
@@ -3246,7 +3246,7 @@ static void do_exec_command(int fd, const char * command,
 	/* Detach from the controlling tty if we have one. Otherwise,
 	   SSH might do something stupid like trying to use it instead
 	   of running $SSH_ASKPASS. Doh. */
-	fd = open("/dev/tty", O_RDONLY);
+	fd = g_open("/dev/tty", O_RDONLY, 0);
 	if (fd != -1) {
 		ioctl(fd, TIOCNOTTY, NULL);
 		close(fd);
