@@ -1,6 +1,6 @@
 /*
  * Claws Mail -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 2005-2007 DINH Viet Hoa and the Claws Mail team
+ * Copyright (C) 2005-2009 DINH Viet Hoa and the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -972,8 +972,7 @@ static void xhdr_run(struct etpan_thread_op * op)
 	if (param->beg == param->end) {
 		r = newsnntp_xhdr_single(param->nntp, param->header, param->beg, param->hdrlist);
 	} else {
-		r = -1;
-		g_warning("XHDR range not implemented\n");
+		r = newsnntp_xhdr_range(param->nntp, param->header, param->beg, param->end, param->hdrlist);
 	}
 	
 	result->error = r;
