@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2007 Andrej Kacian and the Claws Mail team
+ * Copyright (C) 1999-2009 Andrej Kacian and the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,8 +21,7 @@
 #define __COMBOBOX_H__
 
 #include <glib.h>
-#include <gtk/gtkwidget.h>
-#include <gtk/gtkcombobox.h>
+#include <gtk/gtk.h>
 
 enum {
 	COMBOBOX_TEXT,
