@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2007 Hiroyuki Yamamoto and the Claws Mail Team
+ * Copyright (C) 1999-2009 Hiroyuki Yamamoto and the Claws Mail Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -50,7 +50,7 @@ void prefswindow_open_full		(const gchar *title,
 					 gpointer data,
 					 GDestroyNotify func,
 					 gint *save_width, gint *save_height,
-					 gboolean preload_pages, gboolean activate_child,
+					 gboolean preload_pages,
 					 PrefsOpenCallbackFunc open_cb,
 					 PrefsCloseCallbackFunc close_cb);
 
