@@ -1,6 +1,6 @@
 /*
  * Claws Mail -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2007 Colin Leroy <colin@colino.net> 
+ * Copyright (C) 1999-2009 Colin Leroy <colin@colino.net> 
  * and the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
@@ -164,8 +164,8 @@ static void update_extended_buttons (QuickSearch *quicksearch)
 	GtkWidget *expr_btn = quicksearch->search_condition_expression;
 	GtkWidget *ext_btn = quicksearch->search_description;
 
-	g_return_if_fail(expr_btn != NULL);
-	g_return_if_fail(ext_btn != NULL);
+	cm_return_if_fail(expr_btn != NULL);
+	cm_return_if_fail(ext_btn != NULL);
 
 	if (prefs_common.summary_quicksearch_type == QUICK_SEARCH_EXTENDED) {
 		gtk_widget_show(expr_btn);
@@ -267,7 +267,7 @@ static gboolean searchbar_pressed(GtkWidget *widget, GdkEventKey *event,
 		quicksearch->in_typing = FALSE;
 
 		str = quicksearch_get_text(quicksearch);
-		g_return_val_if_fail(str != NULL, TRUE);
+		cm_return_val_if_fail(str != NULL, TRUE);
 
 		/* If the string entry is empty -> hide quicksearch bar. If not -> empty it */
 		if (!*str) {
@@ -492,7 +492,7 @@ static void search_condition_expr_done(MatcherList * matchers)
 {
 	gchar *str;
 
-	g_return_if_fail(
+	cm_return_if_fail(
 			mainwindow_get_mainwindow()->summaryview->quicksearch != NULL);
 
 	if (matchers == NULL)
@@ -515,7 +515,7 @@ static gboolean search_condition_expr(GtkMenuItem *widget, gpointer data)
 	gchar * cond_str;
 	MatcherList * matchers = NULL;
 	
-	g_return_val_if_fail(
+	cm_return_val_if_fail(
 			mainwindow_get_mainwindow()->summaryview->quicksearch != NULL,
 			FALSE);
 
@@ -654,7 +654,7 @@ QuickSearch *quicksearch_new()
 
 	vbox = gtk_vbox_new(TRUE, 0);
 	gtk_box_pack_start(GTK_BOX(vbox), search_string_entry, FALSE, FALSE, 0);
-	gtk_box_pack_start(GTK_BOX(hbox_search), vbox, FALSE, FALSE, 4);
+	gtk_box_pack_start(GTK_BOX(hbox_search), vbox, TRUE, TRUE, 4);
 
 	gtk_widget_show(vbox);
 	gtk_widget_show(search_string_entry);
