@@ -1228,12 +1228,20 @@ int main(int argc, char *argv[])
 		/* If migration failed or the user didn't want to do it,
 		 * we create a new one (and we'll hit wizard later). 
 		 */
-		if (r == FALSE && !is_dir_exist(RC_DIR) && make_dir(RC_DIR) < 0) {
-#ifdef G_OS_WIN32
-			win32_close_log();
+		if (r == FALSE && !is_dir_exist(RC_DIR)) {
+#ifdef G_OS_UNIX
+			if (copy_dir(SYSCONFDIR "/skel/.claws-mail", RC_DIR) < 0) {
 #endif
-			exit(1);
-	}
+				if (!is_dir_exist(RC_DIR) && make_dir(RC_DIR) < 0) {
+#ifdef G_OS_WIN32
+					win32_close_log();
+#endif
+					exit(1);
+				}
+#ifdef G_OS_UNIX
+			}
+#endif
+		}
 	}
 	
 
@@ -1383,6 +1391,11 @@ int main(int argc, char *argv[])
 	prefs_account_init();
 	account_read_config_all();
 
+#ifdef HAVE_LIBETPAN
+	imap_main_init(prefs_common.skip_ssl_cert_check);
+	imap_main_set_timeout(prefs_common.io_timeout_secs);
+	nntp_main_init(prefs_common.skip_ssl_cert_check);
+#endif	
 	/* If we can't read a folder list or don't have accounts,
 	 * it means the configuration's not done. Either this is
 	 * a brand new install, either a failed/refused migration.
@@ -1438,11 +1451,6 @@ int main(int argc, char *argv[])
 	if (claws_crashed())
 		main_window_popup(mainwin);
 
-#ifdef HAVE_LIBETPAN
-	imap_main_init(prefs_common.skip_ssl_cert_check);
-	imap_main_set_timeout(prefs_common.io_timeout_secs);
-	nntp_main_init(prefs_common.skip_ssl_cert_check);
-#endif	
 	account_set_missing_folder();
 	folder_set_missing_folders();
 	folderview_set(folderview);
