@@ -1647,14 +1647,16 @@ static void folder_regexp_test_cb(GtkWidget *widget, gpointer data)
 	if (!regexp || !regexp[0]) {
 		gtk_widget_modify_base(page->entry_simplify_subject,
 				GTK_STATE_NORMAL, NULL);
-		if (test_string) {
+		if (test_string)
 			gtk_entry_set_text(GTK_ENTRY(page->entry_regexp_test_result), test_string);
-			g_free(test_string);
-		}
+			
+		g_free(test_string);
+		g_free(regexp);
 		return;
 	}
 
 	if (!test_string || !test_string[0]) {
+		g_free(test_string);
 		g_free(regexp);
 		return;
 	}
