@@ -378,7 +378,7 @@ static void prefs_summaries_create_widget(PrefsPage *_page, GtkWindow *window,
 
 	PACK_CHECK_BUTTON
 		(vbox2, checkbtn_reopen_last_folder,
-		 _("Open last opened folder at startup"));
+		 _("Open last opened folder at start-up"));
 
 	label_ng_abbrev = gtk_label_new
 		(_("Abbreviate newsgroup names longer than"));
@@ -561,7 +561,7 @@ static void prefs_summaries_create_widget(PrefsPage *_page, GtkWindow *window,
 
 	PACK_CHECK_BUTTON
 		(vbox1, checkbtn_ask_mark_all_read,
-		 _("Confirm before marking all mails in a folder as read"));
+		 _("Confirm before marking all messages in a folder as read"));
 	PACK_CHECK_BUTTON
 		(vbox1, checkbtn_transhdr,
 		 _("Translate header names"));
@@ -767,15 +767,8 @@ static void date_format_entry_on_change(GtkEditable *editable,
 	text = gtk_editable_get_chars(editable, 0, -1);
 	if (text)
 		fast_strftime(buffer, sizeof buffer, text, cal_time); 
-	g_free(text);
 
-	text = conv_codeset_strdup(buffer,
-				   conv_get_locale_charset_str(),
-				   CS_UTF_8);
-	if (!text)
-		text = g_strdup(buffer);
-
-	gtk_label_set_text(example, text);
+	gtk_label_set_text(example, buffer);
 
 	g_free(text);
 }
