@@ -77,6 +77,7 @@ typedef struct {
 	gboolean rendering;
 	gint page_width;
 	gint page_height;
+	GtkPrintContext *context;
 } PreviewData;
 
 /* callbacks */
@@ -279,6 +280,10 @@ void printing_print_full(GtkWindow *parent, PrintRenderer *renderer, gpointer re
 	/* Config for printing */
 	gtk_print_operation_set_print_settings(op, settings);
 	gtk_print_operation_set_default_page_setup(op, page_setup);
+#if GTK_CHECK_VERSION(2, 18, 0)
+        /* enable Page Size and Orientation in the print dialog */
+	gtk_print_operation_set_embed_page_setup(op, TRUE);
+#endif
 
 	/* signals */
 	g_signal_connect(op, "begin_print", G_CALLBACK(renderer->cb_begin_print), print_data);
@@ -615,6 +620,7 @@ static void cb_preview_ready(GtkPrintOperationPreview *preview,
 
 	preview_data->pages_to_print = g_list_reverse(preview_data->pages_to_print);
 	preview_data->current_page = preview_data->pages_to_print;
+	preview_data->context = context;
 
 	g_signal_connect(preview_data->area, "expose_event",
 			 G_CALLBACK(cb_preview_expose),
@@ -659,6 +665,7 @@ static gboolean cb_preview_expose(GtkWidget *widget, GdkEventExpose *event,
 	GdkColor white;
 	GdkColor black;
 	GdkColor gray;
+	cairo_t *cr;
 
 	debug_print("preview_expose (current %p)\n", preview_data->current_page);
 	gdk_window_clear(preview_data->area->window);
@@ -696,6 +703,10 @@ static gboolean cb_preview_expose(GtkWidget *widget, GdkEventExpose *event,
 
 	g_object_unref(gc);
 
+	cr = gdk_cairo_create(preview_data->area->window);
+	gtk_print_context_set_cairo_context(preview_data->context, cr, PREVIEW_SCALE, PREVIEW_SCALE);
+	cairo_destroy(cr);
+
 	if (preview_data->current_page) {
 		preview_data->rendering = TRUE;
 		gtk_widget_set_sensitive(preview_data->close, FALSE);
