@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2007 Hiroyuki Yamamoto and the Claws Mail team
+ * Copyright (C) 1999-2009 Hiroyuki Yamamoto and the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -400,8 +400,8 @@ GtkWidget *stock_pixmap_widget(GtkWidget *window, StockPixmap icon)
 {
 	GdkPixbuf *pixbuf;
 
-	g_return_val_if_fail(window != NULL, NULL);
-	g_return_val_if_fail(icon >= 0 && icon < N_STOCK_PIXMAPS, NULL);
+	cm_return_val_if_fail(window != NULL, NULL);
+	cm_return_val_if_fail(icon >= 0 && icon < N_STOCK_PIXMAPS, NULL);
 
 	if (stock_pixbuf_gdk(window, icon, &pixbuf) != -1)
 		return gtk_image_new_from_pixbuf(pixbuf);
@@ -422,7 +422,7 @@ gint stock_pixbuf_gdk(GtkWidget *window, StockPixmap icon, GdkPixbuf **pixbuf)
 	if (pixbuf)
 		*pixbuf = NULL;
 		
-	g_return_val_if_fail(icon >= 0 && icon < N_STOCK_PIXMAPS, -1);
+	cm_return_val_if_fail(icon >= 0 && icon < N_STOCK_PIXMAPS, -1);
 
 	pix_d = &pixmaps[icon];
 
@@ -476,7 +476,7 @@ try_next_extension:
 		}
 	}
 
-	g_return_val_if_fail(pix_d->pixbuf != NULL, -1);
+	cm_return_val_if_fail(pix_d->pixbuf != NULL, -1);
 
 	if (pixbuf)
 		*pixbuf = pix_d->pixbuf;
@@ -486,80 +486,6 @@ try_next_extension:
 	return 0;
 }
 
-/* create GdkPixmap if it has not created yet */
-gint stock_pixmap_gdk(GtkWidget *window, StockPixmap icon,
-		      GdkPixmap **pixmap, GdkBitmap **mask)
-{
-	StockPixmapData *pix_d;
-	static const char *extension[]={".png", ".xpm", NULL};
-	int i = 0;
-	gboolean theme_changed = FALSE;
-
-	if (pixmap) *pixmap = NULL;
-	if (mask)   *mask   = NULL;
-
-	g_return_val_if_fail(window != NULL, -1);
-	g_return_val_if_fail(icon >= 0 && icon < N_STOCK_PIXMAPS, -1);
-
-	pix_d = &pixmaps[icon];
-
-	theme_changed = (strcmp2(pix_d->icon_path, prefs_common.pixmap_theme_path) != 0);
-	if (!pix_d->pixmap || theme_changed) {
-		GdkPixmap *pix = NULL;
-
-		if (theme_changed && pix_d->pixbuf) {
-			g_object_unref(pix_d->pixbuf);
-			pix_d->pixbuf = NULL;
-		}
-
-		if (strcmp(prefs_common.pixmap_theme_path, DEFAULT_PIXMAP_THEME) != 0) {
-			if ( is_dir_exist(prefs_common.pixmap_theme_path) ) {
-				char *icon_file_name; 
-try_next_extension:
-				icon_file_name = g_strconcat(prefs_common.pixmap_theme_path,
-							     G_DIR_SEPARATOR_S,
-							     pix_d->file,
-							     extension[i],
-							     NULL);
-				if (is_file_exist(icon_file_name))
-					PIXMAP_CREATE_FROM_FILE(window, pix, pix_d->mask, icon_file_name);
-				if (pix) {
-					g_free(pix_d->icon_path);
-					pix_d->icon_path = g_strdup(prefs_common.pixmap_theme_path);
-				}
-				g_free(icon_file_name);
-				if (!pix) {
-					i++;
-					if (extension[i])
-						goto try_next_extension;
-				}
-			} else {
-				/* even the path does not exist (deleted between two sessions), so
-				set the preferences to the internal theme */
-				prefs_common.pixmap_theme_path = g_strdup(DEFAULT_PIXMAP_THEME);
-			}
-		}
-		pix_d->pixmap = pix;
-	}
-
-	if (!pix_d->pixmap) {
-		PIXMAP_CREATE(window, pix_d->pixmap, pix_d->mask, pix_d->data);
-		if (pix_d->pixmap) {
-			g_free(pix_d->icon_path);
-			pix_d->icon_path = g_strdup(DEFAULT_PIXMAP_THEME);	
-		}
-	}
-
-	g_return_val_if_fail(pix_d->pixmap != NULL, -1);
-	
-	if (pixmap) 
-		*pixmap = pix_d->pixmap;
-	if (mask)   
-		*mask   = pix_d->mask;
-
-	return 0;
-}
-
 static void stock_pixmap_find_themes_in_dir(GList **list, const gchar *dirname)
 {
 	struct dirent *d;
@@ -601,6 +527,19 @@ static void stock_pixmap_find_themes_in_dir(GList **list, const gchar *dirname)
 	closedir(dp);
 }
 
+gchar *stock_pixmap_get_system_theme_dir_for_theme(const gchar *theme)
+{
+	const gchar *sep = NULL;
+	if (theme && *theme)
+		sep = G_DIR_SEPARATOR_S;
+#ifndef G_OS_WIN32
+	return g_strconcat(PACKAGE_DATA_DIR, G_DIR_SEPARATOR_S,
+	        	   PIXMAP_THEME_DIR, sep, theme, NULL);
+#else
+	return g_strconcat(get_themes_dir(), sep, theme, NULL);
+#endif
+}
+
 GList *stock_pixmap_themes_list_new(void)
 {
 	gchar *defaulttheme;
@@ -611,11 +550,9 @@ GList *stock_pixmap_themes_list_new(void)
 	defaulttheme = g_strdup(DEFAULT_PIXMAP_THEME);
 	userthemes   = g_strconcat(get_rc_dir(), G_DIR_SEPARATOR_S, 
 				   PIXMAP_THEME_DIR, NULL);
-	systemthemes = g_strconcat(PACKAGE_DATA_DIR, G_DIR_SEPARATOR_S,
-				   PIXMAP_THEME_DIR, NULL);
+	systemthemes = stock_pixmap_get_system_theme_dir_for_theme(NULL);
 
 	list = g_list_append(list, defaulttheme);
-	
 	stock_pixmap_find_themes_in_dir(&list, userthemes);
 	stock_pixmap_find_themes_in_dir(&list, systemthemes);
 
@@ -635,7 +572,8 @@ void stock_pixmap_themes_list_free(GList *list)
 
 gchar *stock_pixmap_get_name (StockPixmap icon)
 {
-	g_return_val_if_fail(icon >= 0 && icon < N_STOCK_PIXMAPS, NULL);
+	if (icon < 0 || icon >= N_STOCK_PIXMAPS)
+		return NULL;
 	
 	return pixmaps[icon].file;
 
@@ -661,10 +599,10 @@ static gboolean pixmap_with_overlay_expose_event_cb(GtkWidget *widget, GdkEventE
 	gint top = 0;
 
 	if (data->is_pixmap) {
-		g_return_val_if_fail(data->base_pixmap != NULL, FALSE);
-		g_return_val_if_fail(data->base_mask != NULL, FALSE);
+		cm_return_val_if_fail(data->base_pixmap != NULL, FALSE);
+		cm_return_val_if_fail(data->base_mask != NULL, FALSE);
 	} else {
-		g_return_val_if_fail(data->base_pixbuf != NULL, FALSE);
+		cm_return_val_if_fail(data->base_pixbuf != NULL, FALSE);
 	}
 	gc_pix = gdk_gc_new((GdkWindow *)drawable);
 						 
@@ -752,8 +690,8 @@ static gboolean pixmap_with_overlay_expose_event_cb(GtkWidget *widget, GdkEventE
 	}
 	if (data->position != OVERLAY_NONE) {
 		if (data->is_pixmap) {
-			g_return_val_if_fail(data->overlay_pixmap != NULL, FALSE);
-			g_return_val_if_fail(data->overlay_mask != NULL, FALSE);
+			cm_return_val_if_fail(data->overlay_pixmap != NULL, FALSE);
+			cm_return_val_if_fail(data->overlay_mask != NULL, FALSE);
 			gdk_gc_set_tile(gc_pix, data->overlay_pixmap);
 			gdk_gc_set_clip_mask(gc_pix, data->overlay_mask);
 
@@ -763,7 +701,7 @@ static gboolean pixmap_with_overlay_expose_event_cb(GtkWidget *widget, GdkEventE
 			gdk_draw_rectangle(drawable, gc_pix, TRUE, left, top, 
 				   data->overlay_width, data->overlay_height);
 		} else {
-			g_return_val_if_fail(data->overlay_pixbuf != NULL, FALSE);
+			cm_return_val_if_fail(data->overlay_pixbuf != NULL, FALSE);
 			gdk_draw_pixbuf(drawable, gc_pix, data->overlay_pixbuf, 
 				0, 0, left, top,
 				-1, -1, GDK_RGB_DITHER_NONE, 0, 0);
